==> kubernetes-model-autoscaling-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ContainerResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ContainerResourceMetricSourceFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ContainerResourceMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getContainer();
  public A withContainer(java.lang.String container);
  public java.lang.Boolean hasContainer();
  
  /**
   * Method is deprecated. use withContainer instead.
   */
  @java.lang.Deprecated
  public A withNewContainer(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Integer getTargetAverageUtilization();
  public A withTargetAverageUtilization(java.lang.Integer targetAverageUtilization);
  public java.lang.Boolean hasTargetAverageUtilization();
  public io.fabric8.kubernetes.api.model.Quantity getTargetAverageValue();
  public A withTargetAverageValue(io.fabric8.kubernetes.api.model.Quantity targetAverageValue);
  public java.lang.Boolean hasTargetAverageValue();
  public A withNewTargetAverageValue(java.lang.String amount,java.lang.String format);
  public A withNewTargetAverageValue(java.lang.String amount);
  
}

==> kubernetes-model-autoscaling-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ContainerResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ContainerResourceMetricSourceFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ContainerResourceMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getContainer();
  public A withContainer(java.lang.String container);
  public java.lang.Boolean hasContainer();
  
  /**
   * Method is deprecated. use withContainer instead.
   */
  @java.lang.Deprecated
  public A withNewContainer(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Integer getTargetAverageUtilization();
  public A withTargetAverageUtilization(java.lang.Integer targetAverageUtilization);
  public java.lang.Boolean hasTargetAverageUtilization();
  public io.fabric8.kubernetes.api.model.Quantity getTargetAverageValue();
  public A withTargetAverageValue(io.fabric8.kubernetes.api.model.Quantity targetAverageValue);
  public java.lang.Boolean hasTargetAverageValue();
  public A withNewTargetAverageValue(java.lang.String amount,java.lang.String format);
  public A withNewTargetAverageValue(java.lang.String amount);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
